@@ -10,6 +10,7 @@ from .const import (
     STATUS_RESPONSE_INPUTS,
     STATUS_RESPONSE_INPUTS_INPUT,
     INFO_VALUE_SWITCH,
+    INFO_VALUE_DEVICE_TEMP,
     STATUS_RESPONSE_METERS,
     STATUS_RESPONSE_METERS_POWER,
     INFO_VALUE_CURRENT_CONSUMPTION
@@ -27,12 +28,12 @@ class Dimmer(Device):
         self.dim_pos = dim_pos
         self.info_values = {}
 
-    def update(self, data):
-        new_state = data.get(self.state_pos) == 1
-        self.brightness = data.get(self.dim_pos)
+    def update_coap(self, payload):
+        new_state = self.coap_get(payload, self.state_pos) == 1
+        self.brightness = self.coap_get(payload, self.dim_pos)
         values = {'brightness': self.brightness}
         for idx in range(0, 2):
-            value = data.get(131 + idx*10)
+            value = self.coap_get(payload, 131)
             if value is not None:
                 self.info_values[INFO_VALUE_SWITCH + "_" + str(idx+1)] = value > 0
         #todo, read consumption when firmware fixed
